@@ -20,7 +20,7 @@ static int democount;
 static demoresult* results;
 static char *datadir = NOTCURSES_SHARE;
 
-static const char DEFAULT_DEMO[] = "ixezcydthnbgmarwuvlsfjqo";
+static const char DEFAULT_DEMO[] = "ixezcydthnbkgmarwuvlsfjqo";
 
 atomic_bool interrupted = ATOMIC_VAR_INIT(false);
 // checked following demos, whether aborted, failed, or otherwise
@@ -84,7 +84,7 @@ static struct {
   { "highcon", highcontrast_demo, false, },
   { "intro", intro, false, },
   { "jungle", jungle_demo, true, },
-  { NULL, NULL, false, }, // FIXME
+  { "keller", keller_demo, true, },
   { "luigi", luigi_demo, true, },
   { "mojibake", mojibake_demo, false, },
   { "normal", normal_demo, false, },
@@ -169,7 +169,7 @@ usage(const char* exe, int status){
   int printed = 0;
   for(size_t i = 0 ; i < sizeof(demos) / sizeof(*demos) ; ++i){
     if(demos[i].name){
-      if(printed % 6 == 0){
+      if(printed % 5 == 0){
         fprintf(out, " ");
       }
       // U+24D0: CIRCLED LATIN SMALL LETTER A
@@ -177,12 +177,12 @@ usage(const char* exe, int status){
       fprintf(out, "%lc ", *demos[i].name - 'a' + 0x24d0);
       if(n) ncdirect_fg_rgb8(n, 0xff, 0xff, 0xff);
       fprintf(out, "%-*.*s", 8, 8, demos[i].name + 1);
-      if(++printed % 6 == 0){
+      if(++printed % 5 == 0){
         fprintf(out, "\n");
       }
     }
   }
-  if(printed % 6){
+  if(printed % 5){
     fprintf(out, "\n");
   }
   ncdirect_stop(n);
@@ -398,7 +398,7 @@ summary_json(FILE* f, const char* spec, int rows, int cols){
 }
 
 static int
-summary_table(struct ncdirect* nc, const char* spec){
+summary_table(struct ncdirect* nc, const char* spec, bool canimage, bool canvideo){
   bool failed = false;
   uint64_t totalbytes = 0;
   long unsigned totalframes = 0;
@@ -486,15 +486,16 @@ summary_table(struct ncdirect* nc, const char* spec){
   if(failed){
     fprintf(stderr, "\nError running demo.\nIs \"%s\" the correct data path? Supply it with -p.\n", datadir);
   }
+  ncdirect_fg_rgb8(nc, 0xfe, 0x20, 0x76); // PANTONE Strong Red C + 3x0x20
+  fflush(stdout); // in case we print to stderr below, we want color from above
 #ifdef DFSG_BUILD
-  ncdirect_fg_rgb8(nc, 0xfe, 0x20, 0x76); // PANTONE Strong Red C + 3x0x20
-  fflush(stdout); // in case we print to stderr below, we want color from above
   fprintf(stderr, "\nDFSG version. Some demos are unavailable.\n");
-#elif !defined(USE_MULTIMEDIA) // don't double-print for DFSG
-  ncdirect_fg_rgb8(nc, 0xfe, 0x20, 0x76); // PANTONE Strong Red C + 3x0x20
-  fflush(stdout); // in case we print to stderr below, we want color from above
-  fprintf(stderr, "\nNo multimedia support. Some demos are unavailable.\n");
 #endif
+  if(!canimage){
+    fprintf(stderr, "\nNo multimedia support. Some demos are unavailable.\n");
+  }else if(!canvideo){
+    fprintf(stderr, "\nNo video support. Some demos are unavailable.\n");
+  }
   return failed;
 }
 
@@ -544,6 +545,8 @@ int main(int argc, char** argv){
   if((nc = notcurses_init(&nopts, NULL)) == NULL){
     return EXIT_FAILURE;
   }
+  const bool canimage = notcurses_canopen_images(nc);
+  const bool canvideo = notcurses_canopen_videos(nc);
   if(notcurses_mouse_enable(nc)){
     goto err;
   }
@@ -614,7 +617,7 @@ int main(int argc, char** argv){
     return EXIT_FAILURE;
   }
   // reinitialize without alternate screen to do some coloring
-  if(summary_table(ncd, spec)){
+  if(summary_table(ncd, spec, canimage, canvideo)){
     ncdirect_stop(ncd);
     return EXIT_FAILURE;
   }
