@@ -444,9 +444,7 @@ int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
 //fprintf(stderr, "render: %d+%d of %d/%d stride %u %p\n", leny, lenx, ncv->rows, ncv->cols, ncv->rowstride, ncv->data);
   ncplane_options nopts = {
     .y = 0,
-    .horiz = {
-      .x = 0,
-    },
+    .x = 0,
     .rows = disprows / encoding_y_scale(bset),
     .cols = dispcols / encoding_x_scale(bset),
     .userptr = nullptr,
@@ -469,12 +467,12 @@ int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
   if(ncdirect_dump_plane(n, faken, xoff)){
     return -1;
   }
+  ncdirect_fg_default(n);
+  ncdirect_bg_default(n);
   while(fflush(stdout) == EOF && errno == EAGAIN){
     ;
   }
   free_plane(faken);
-  ncdirect_fg_default(n);
-  ncdirect_bg_default(n);
   return 0;
 }
 
