@@ -258,7 +258,14 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
     return -1;
   }
 //fprintf(stderr, "p tplacement: %p base %d/%d len %d/%d frontiery %d %d dir %d\n", t, begy, begx, leny, lenx, frontiertop, frontierbottom, direction);
-  ncplane* fp = ncplane_new(nr->p, leny, lenx, begy, begx, NULL, "tab");
+  struct ncplane_options nopts = {
+    .y = begy,
+    .x = begx,
+    .rows = leny,
+    .cols = lenx,
+    .name = "tab",
+  };
+  ncplane* fp = ncplane_create(nr->p, &nopts);
   if((t->p = fp) == NULL){
 //fprintf(stderr, "failure creating border plane %d %d %d %d\n", leny, lenx, begy, begx);
     return -1;
@@ -278,7 +285,14 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
   }
   if(cbleny - cby + 1 > 0){
 //fprintf(stderr, "cbp placement %dx%d @ %dx%d\n", cbleny, cblenx, cby, cbx);
-    t->cbp = ncplane_new(t->p, cbleny, cblenx, cby, cbx, NULL, "tdat");
+    struct ncplane_options dnopts = {
+      .y = cby,
+      .x = cbx,
+      .rows = cbleny,
+      .cols = cblenx,
+      .name = "tdat",
+    };
+    t->cbp = ncplane_create(t->p, &dnopts);
     if(t->cbp == NULL){
 //fprintf(stderr, "failure creating data plane %d %d %d %d\n", cbleny, cblenx, cby, cbx);
       ncplane_destroy(t->p);
@@ -290,7 +304,7 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
     int ll = t->cbfxn(t, direction == DIRECTION_DOWN);
 //fprintf(stderr, "RETURNRETURNRETURN %p %d (%d, %d, %d) DIR %d\n", t, ll, cby, cbleny, leny, direction);
     if(ll > cbleny){
-      logwarn(nr->p->nc, "Tablet callback returned %d lines, %d allowed\n", ll, cbleny);
+      logwarn(ncplane_notcurses(nr->p), "Tablet callback returned %d lines, %d allowed\n", ll, cbleny);
       ll = cbleny;
     }
     if(ll != cbleny){
@@ -654,7 +668,7 @@ int ncreel_redraw(ncreel* nr){
   if(focused){
 //fprintf(stderr, "drawing focused tablet %p dir: %d fulcrum: %d!\n", focused, nr->direction, fulcrum);
     if(ncreel_draw_tablet(nr, focused, fulcrum, fulcrum, DIRECTION_DOWN)){
-      logerror(nr->p->nc, "Error drawing tablet\n");
+      logerror(ncplane_notcurses(nr->p), "Error drawing tablet\n");
       return -1;
     }
 //fprintf(stderr, "drew focused tablet %p -> %p lastdir: %d!\n", focused, focused->p, nr->direction);
@@ -666,33 +680,33 @@ int ncreel_redraw(ncreel* nr){
     if(nr->direction == LASTDIRECTION_DOWN){
       otherend = draw_previous_tablets(nr, otherend, &frontiertop, frontierbottom);
       if(otherend == NULL){
-        logerror(nr->p->nc, "Error drawing higher tablets\n");
+        logerror(ncplane_notcurses(nr->p), "Error drawing higher tablets\n");
         return -1;
       }
       otherend = draw_following_tablets(nr, otherend, frontiertop, &frontierbottom);
     }else{ // DIRECTION_UP
       otherend = draw_previous_tablets(nr, otherend, &frontiertop, frontierbottom);
       if(otherend == NULL){
-        logerror(nr->p->nc, "Error drawing higher tablets\n");
+        logerror(ncplane_notcurses(nr->p), "Error drawing higher tablets\n");
         return -1;
       }
       otherend = draw_following_tablets(nr, otherend, frontiertop, &frontierbottom);
     }
     if(otherend == NULL){
-      logerror(nr->p->nc, "Error drawing following tablets\n");
+      logerror(ncplane_notcurses(nr->p), "Error drawing following tablets\n");
       return -1;
     }
-//notcurses_debug(nr->p->nc, stderr);
+//notcurses_debug(ncplane_notcurses(nr->p), stderr);
     if(tighten_reel(nr)){
-      logerror(nr->p->nc, "Error tightening reel\n");
+      logerror(ncplane_notcurses(nr->p), "Error tightening reel\n");
       return -1;
     }
-//notcurses_debug(nr->p->nc, stderr);
+//notcurses_debug(ncplane_notcurses(nr->p), stderr);
   }
   nr->vft = nr->tablets; // update the visually-focused tablet pointer
 //fprintf(stderr, "DONE ARRANGING\n");
   if(draw_ncreel_borders(nr)){
-    logerror(nr->p->nc, "Error drawing reel borders\n");
+    logerror(ncplane_notcurses(nr->p), "Error drawing reel borders\n");
     return -1; // enforces specified dimensional minima
   }
   return 0;
@@ -704,7 +718,7 @@ validate_ncreel_opts(ncplane* n, const ncreel_options* ropts){
     return false;
   }
   if(ropts->flags > NCREEL_OPTION_CIRCULAR){
-    logwarn(n->nc, "Provided unsupported flags %016lx\n", ropts->flags);
+    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016lx\n", ropts->flags);
   }
   if(ropts->flags & NCREEL_OPTION_CIRCULAR){
     if(!(ropts->flags & NCREEL_OPTION_INFINITESCROLL)){
@@ -768,7 +782,7 @@ nctablet* ncreel_add(ncreel* nr, nctablet* after, nctablet *before,
   nctablet* t;
   if(after && before){
     if(after->prev != before || before->next != after){
-      logerror(nr->p->nc, "bad before (%p) / after (%p) spec\n", before, after);
+      logerror(ncplane_notcurses(nr->p), "bad before (%p) / after (%p) spec\n", before, after);
       return NULL;
     }
   }else if(!after && !before){
