@@ -152,7 +152,17 @@ TEST_CASE("Cell") {
     CHECK(0 == cell_set_fg_rgb8(&c, 0xff, 0xff, 0xff));
     CHECK(0 == cell_set_fg_alpha(&c, CELL_ALPHA_HIGHCONTRAST));
     CHECK(0 == cell_set_bg_alpha(&c, CELL_ALPHA_TRANSPARENT));
-    auto np = ncplane_new(n_, 1, 1, 0, 0, nullptr, nullptr);
+    struct ncplane_options nopts = {
+      .y = 0,
+      .x = 0,
+      .rows = 1,
+      .cols = 1,
+      .userptr = nullptr,
+      .name = nullptr,
+      .resizecb = nullptr,
+      .flags = 0,
+    };
+    auto np = ncplane_create(n_, &nopts);
     REQUIRE(nullptr != np);
     CHECK(1 == ncplane_putc(np, &c));
     cell_load_char(np, &c, '*');
@@ -181,7 +191,17 @@ TEST_CASE("Cell") {
     CHECK(0 == cell_set_fg_rgb8(&c, 0xff, 0xff, 0xff));
     CHECK(0 == cell_set_fg_alpha(&c, CELL_ALPHA_HIGHCONTRAST));
     CHECK(0 == cell_set_bg_alpha(&c, CELL_ALPHA_TRANSPARENT));
-    auto np = ncplane_new(n_, 1, 1, 0, 0, nullptr, nullptr);
+    struct ncplane_options nopts = {
+      .y = 0,
+      .x = 0,
+      .rows = 1,
+      .cols = 1,
+      .userptr = nullptr,
+      .name = nullptr,
+      .resizecb = nullptr,
+      .flags = 0,
+    };
+    auto np = ncplane_create(n_, &nopts);
     REQUIRE(nullptr != np);
     CHECK(1 == ncplane_putc(np, &c));
     cell_load_char(np, &c, '*');
@@ -210,7 +230,17 @@ TEST_CASE("Cell") {
     CHECK(0 == cell_set_fg_rgb8(&c, 0x0, 0x0, 0x0));
     CHECK(0 == cell_set_fg_alpha(&c, CELL_ALPHA_HIGHCONTRAST));
     CHECK(0 == cell_set_bg_alpha(&c, CELL_ALPHA_TRANSPARENT));
-    auto np = ncplane_new(n_, 1, 1, 0, 0, nullptr, nullptr);
+    struct ncplane_options nopts = {
+      .y = 0,
+      .x = 0,
+      .rows = 1,
+      .cols = 1,
+      .userptr = nullptr,
+      .name = nullptr,
+      .resizecb = nullptr,
+      .flags = 0,
+    };
+    auto np = ncplane_create(n_, &nopts);
     REQUIRE(nullptr != np);
     CHECK(1 == ncplane_putc(np, &c));
     cell_load_char(np, &c, '*');
@@ -239,7 +269,17 @@ TEST_CASE("Cell") {
     CHECK(0 == cell_set_fg_rgb8(&c, 0x0, 0x0, 0x0));
     CHECK(0 == cell_set_fg_alpha(&c, CELL_ALPHA_HIGHCONTRAST));
     CHECK(0 == cell_set_bg_alpha(&c, CELL_ALPHA_TRANSPARENT));
-    auto np = ncplane_new(n_, 1, 1, 0, 0, nullptr, nullptr);
+    struct ncplane_options nopts = {
+      .y = 0,
+      .x = 0,
+      .rows = 1,
+      .cols = 1,
+      .userptr = nullptr,
+      .name = nullptr,
+      .resizecb = nullptr,
+      .flags = 0,
+    };
+    auto np = ncplane_create(n_, &nopts);
     REQUIRE(nullptr != np);
     CHECK(1 == ncplane_putc(np, &c));
     cell_load_char(np, &c, '*');
@@ -269,7 +309,17 @@ TEST_CASE("Cell") {
     // top has a background of white
     CHECK(0 == cell_set_bg_rgb8(&c, 0xff, 0xff, 0xff));
     CHECK(0 == cell_set_fg_alpha(&c, CELL_ALPHA_TRANSPARENT));
-    auto np = ncplane_new(n_, 1, 1, 0, 0, nullptr, nullptr);
+    struct ncplane_options nopts = {
+      .y = 0,
+      .x = 0,
+      .rows = 1,
+      .cols = 1,
+      .userptr = nullptr,
+      .name = nullptr,
+      .resizecb = nullptr,
+      .flags = 0,
+    };
+    auto np = ncplane_create(n_, &nopts);
     REQUIRE(nullptr != np);
     CHECK(1 == ncplane_putc(np, &c));
     cell_load_char(n_, &c, '*');
